==> nomachine-8.4.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/WaitProcess.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub WaitProcess::BEGIN{package WaitProcess;no warnings;require POSIX;do{
"\x50\x4f\x53\x49\x58"->import ("\x3a\x73\x69\x67\x6e\x61\x6c\x5f\x68",
"\x3a\x65\x72\x72\x6e\x6f\x5f\x68",
"\x3a\x73\x79\x73\x5f\x77\x61\x69\x74\x5f\x68")};}sub WaitProcess::BEGIN{package
 WaitProcess;no warnings;require Exception::Internal;do{
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
import};}package WaitProcess;no warnings;(our $errorNoProcessToWait=(-
(0x16d9+ 450-0x189a)));(our $statusRunning=(0x0b81+ 1579-0x11ac));(our 
$statusExited=(0x143c+ 491-0x1626));(our $statusStopped=(0x1925+ 2963-0x24b6));(
our $statusDied=(0x1974+ 3260-0x262d));my ($__resultStatus);my ($__resultPid);my (
$__parameterPid);my ($__parameterOptions);(my $__returnedStatus=
$errorNoProcessToWait);sub waitProcess{($__parameterPid=shift (@_));(
$__parameterOptions=shift (@_));my ($waitpidOption);(my $timeOut=
(0x0e23+ 4226-0x1ea5));if (($__parameterOptions gt (0x1a5c+ 443-0x1c17))){(
$waitpidOption=$NXBits::WAIT_UNTRACED);($timeOut=$__parameterOptions);
Logger::debug (((((
"\x77\x61\x69\x74\x69\x6e\x67\x20\x70\x72\x6f\x63\x65\x73\x73\x3a\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27"
.$__parameterPid)."\x27\x20\x75\x73\x69\x6e\x67\x20").$timeOut).
"\x73\x20\x61\x73\x20\x74\x69\x6d\x65\x6f\x75\x74"));}else{($waitpidOption=
$NXBits::WAIT_NOHANG);Logger::debug (((
"\x77\x61\x69\x74\x69\x6e\x67\x20\x70\x72\x6f\x63\x65\x73\x73\x3a\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27"
.$__parameterPid)."\x27"));}(my $timedOut=(0x1072+ 4952-0x23c9));eval{(
$__resultPid=(0x00e8+ 3299-0x0dcb));if (($timeOut==(0x07b6+ 2785-0x1297))){(
$__resultPid=Common::NXProcess::nxwaitpid ($__parameterPid,$waitpidOption));if (
($__resultPid>(0x0f2c+ 2344-0x1854))){($__resultStatus=
Common::NXProcess::getExitValue ($__resultPid));}}else{($__resultPid=
Common::NXProcess::nxwaitpid ($__parameterPid,$waitpidOption,$timeOut));if ((
$__resultPid eq (0x146a+ 1781-0x1b5f))){($timedOut=(0x03f8+ 7239-0x203e));}else{
($__resultStatus=Common::NXProcess::getExitValue ($__parameterPid));($timedOut=
(0x04d7+ 6257-0x1d48));}}};if ($timedOut){Logger::debug (((
"\x72\x65\x61\x63\x68\x65\x64\x20\x74\x69\x6d\x65\x6f\x75\x74\x20\x6f\x66\x20".
$timeOut).((
"\x73\x20\x77\x68\x69\x6c\x65\x20\x77\x61\x69\x74\x69\x6e\x67\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x27"
.$__parameterPid)."\x27")));($__returnedStatus=$statusRunning);return (
$__returnedStatus);}elsif ($@){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (((
"\x55\x6e\x65\x78\x70\x65\x63\x74\x65\x64\x20\x65\x72\x72\x6f\x72\x3a\x20\x27".
$@)."\x27"));}if (($__resultPid==(-(0x1109+ 1933-0x1895)))){Logger::debug (((
"\x6e\x6f\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x3a\x20\x27"
.$__parameterPid)."\x27\x20\x74\x6f\x20\x77\x61\x69\x74"));($__returnedStatus=
$errorNoProcessToWait);return ($__returnedStatus);}if (WIFEXITED (
$__resultStatus)){Logger::debug (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27".
$__parameterPid)."\x27\x20\x68\x61\x73\x20\x65\x78\x69\x74\x65\x64"));(
$__returnedStatus=$statusExited);return ($__returnedStatus);}if (WIFSIGNALED (
$__resultStatus)){Logger::error (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27".
$__parameterPid)."\x27\x20\x68\x61\x73\x20\x64\x69\x65\x64"));($__returnedStatus
=$statusDied);return ($__returnedStatus);}if (WIFSTOPPED ($__resultStatus)){
Logger::error (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27".
$__parameterPid)."\x27\x20\x77\x61\x73\x20\x73\x74\x6f\x70\x70\x65\x64"));(
$__returnedStatus=$statusStopped);return ($__returnedStatus);}($__returnedStatus
=$errorNoProcessToWait);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (((((
"\x55\x6e\x6b\x6e\x6f\x77\x6e\x20\x72\x65\x73\x75\x6c\x74\x20\x73\x74\x61\x74\x75\x73\x20\x27"
.$__resultStatus)."\x27\x20\x66\x6f\x72\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x27"
).$__parameterPid)."\x27"));}sub getPid{if (($__returnedStatus==
$errorNoProcessToWait)){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x61\x6c\x6c\x20\x74\x68\x69\x73\x20\x6d\x65\x74\x68\x6f\x64\x20\x77\x68\x65\x6e\x20\x6c\x61\x73\x74\x20\x72\x65\x73\x75\x6c\x74\x20\x73\x74\x61\x74\x75\x73\x20\x77\x61\x73\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x65\x72\x72\x6f\x72\x4e\x6f\x50\x72\x6f\x63\x65\x73\x73\x54\x6f\x57\x61\x69\x74\x27"
);}Logger::debug ((("\x70\x69\x64\x20\x69\x73\x20\x27".$__resultPid)."\x27"));
return ($__resultPid);}sub getSig{if (($__returnedStatus==$statusDied)){(my $sig
=WTERMSIG ($__resultStatus));Logger::debug (((
"\x73\x69\x67\x6e\x61\x6c\x20\x77\x61\x73\x20\x27".$sig)."\x27"));return ($sig);
}if (($__returnedStatus==$statusStopped)){(my $sig=WSTOPSIG ($__resultStatus));
Logger::debug ((("\x73\x69\x67\x6e\x61\x6c\x20\x77\x61\x73\x20\x27".$sig)."\x27"
));return ($sig);}
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x61\x6c\x6c\x20\x74\x68\x69\x73\x20\x6d\x65\x74\x68\x6f\x64\x2c\x20\x70\x72\x65\x76\x69\x6f\x75\x73\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x73\x74\x61\x74\x75\x73\x20\x77\x61\x73\x20\x6e\x6f\x74\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x73\x74\x61\x74\x75\x73\x53\x74\x6f\x70\x70\x65\x64\x27\x20\x6f\x72\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x73\x74\x61\x74\x75\x73\x44\x69\x65\x64\x27"
);}sub getExitStatus{if (($__returnedStatus==$statusExited)){(my $exitStatus=
WEXITSTATUS ($__resultStatus));Logger::debug (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x65\x78\x69\x74\x20\x73\x74\x61\x74\x75\x73\x20\x69\x73\x20\x27"
.$exitStatus)."\x27"));return ($exitStatus);}
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x61\x6c\x6c\x20\x74\x68\x69\x73\x20\x6d\x65\x74\x68\x6f\x64\x2c\x20\x70\x72\x65\x76\x69\x6f\x75\x73\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x73\x74\x61\x74\x75\x73\x20\x77\x61\x73\x20\x6e\x6f\x74\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x73\x74\x61\x74\x75\x73\x45\x78\x69\x74\x65\x64\x27"
);}return ((0x1b58+ 2827-0x2662));

==> nomachine-8.6.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/WaitProcess.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub WaitProcess::BEGIN{package WaitProcess;no warnings;require POSIX;do{
"\x50\x4f\x53\x49\x58"->import ("\x3a\x73\x69\x67\x6e\x61\x6c\x5f\x68",
"\x3a\x65\x72\x72\x6e\x6f\x5f\x68",
"\x3a\x73\x79\x73\x5f\x77\x61\x69\x74\x5f\x68")};}sub WaitProcess::BEGIN{package
 WaitProcess;no warnings;require Exception::Internal;do{
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
import};}package WaitProcess;no warnings;(our $errorNoProcessToWait=(-
(0x09da+ 5986-0x213b)));(our $statusRunning=(0x0076+ 4633-0x128f));(our 
$statusExited=(0x1ca0+ 726-0x1f75));(our $statusStopped=(0x25ad+  48-0x25db));(
our $statusDied=(0x0ec5+ 3893-0x1df7));my ($__resultStatus);my ($__resultPid);my (
$__parameterPid);my ($__parameterOptions);(my $__returnedStatus=
$errorNoProcessToWait);sub waitProcess{($__parameterPid=shift (@_));(
$__parameterOptions=shift (@_));my ($waitpidOption);(my $timeOut=
(0x12c9+ 3062-0x1ebf));if (($__parameterOptions gt (0x0048+ 8417-0x2129))){(
$waitpidOption=$NXBits::WAIT_UNTRACED);($timeOut=$__parameterOptions);
Logger::debug (((((
"\x77\x61\x69\x74\x69\x6e\x67\x20\x70\x72\x6f\x63\x65\x73\x73\x3a\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27"
.$__parameterPid)."\x27\x20\x75\x73\x69\x6e\x67\x20").$timeOut).
"\x73\x20\x61\x73\x20\x74\x69\x6d\x65\x6f\x75\x74"));}else{($waitpidOption=
$NXBits::WAIT_NOHANG);Logger::debug (((
"\x77\x61\x69\x74\x69\x6e\x67\x20\x70\x72\x6f\x63\x65\x73\x73\x3a\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27"
.$__parameterPid)."\x27"));}(my $timedOut=(0x095d+ 162-0x09fe));eval{(
$__resultPid=(0x1cf1+ 216-0x1dc9));if (($timeOut==(0x10c3+ 3601-0x1ed4))){(
$__resultPid=Common::NXProcess::nxwaitpid ($__parameterPid,$waitpidOption));if (
($__resultPid>(0x006f+ 822-0x03a5))){($__resultStatus=
Common::NXProcess::getExitValue ($__resultPid));}}else{($__resultPid=
Common::NXProcess::nxwaitpid ($__parameterPid,$waitpidOption,$timeOut));if ((
$__resultPid eq (0x1c66+ 553-0x1e8f))){($timedOut=(0x01eb+ 5414-0x1710));}else{(
$__resultStatus=Common::NXProcess::getExitValue ($__parameterPid));($timedOut=
(0x096f+ 743-0x0c56));}}};if ($timedOut){Logger::debug (((
"\x72\x65\x61\x63\x68\x65\x64\x20\x74\x69\x6d\x65\x6f\x75\x74\x20\x6f\x66\x20".
$timeOut).((
"\x73\x20\x77\x68\x69\x6c\x65\x20\x77\x61\x69\x74\x69\x6e\x67\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x27"
.$__parameterPid)."\x27")));($__returnedStatus=$statusRunning);return (
$__returnedStatus);}elsif ($@){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (((
"\x55\x6e\x65\x78\x70\x65\x63\x74\x65\x64\x20\x65\x72\x72\x6f\x72\x3a\x20\x27".
$@)."\x27"));}if (($__resultPid==(-(0x18db+ 3002-0x2494)))){Logger::debug (((
"\x6e\x6f\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x3a\x20\x27"
.$__parameterPid)."\x27\x20\x74\x6f\x20\x77\x61\x69\x74"));($__returnedStatus=
$errorNoProcessToWait);return ($__returnedStatus);}if (WIFEXITED (
$__resultStatus)){Logger::debug (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27".
$__parameterPid)."\x27\x20\x68\x61\x73\x20\x65\x78\x69\x74\x65\x64"));(
$__returnedStatus=$statusExited);return ($__returnedStatus);}if (WIFSIGNALED (
$__resultStatus)){Logger::error (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27".
$__parameterPid)."\x27\x20\x68\x61\x73\x20\x64\x69\x65\x64"));($__returnedStatus
=$statusDied);return ($__returnedStatus);}if (WIFSTOPPED ($__resultStatus)){
Logger::error (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27".
$__parameterPid)."\x27\x20\x77\x61\x73\x20\x73\x74\x6f\x70\x70\x65\x64"));(
$__returnedStatus=$statusStopped);return ($__returnedStatus);}($__returnedStatus
=$errorNoProcessToWait);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (((((
"\x55\x6e\x6b\x6e\x6f\x77\x6e\x20\x72\x65\x73\x75\x6c\x74\x20\x73\x74\x61\x74\x75\x73\x20\x27"
.$__resultStatus)."\x27\x20\x66\x6f\x72\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x27"
).$__parameterPid)."\x27"));}sub getPid{if (($__returnedStatus==
$errorNoProcessToWait)){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x61\x6c\x6c\x20\x74\x68\x69\x73\x20\x6d\x65\x74\x68\x6f\x64\x20\x77\x68\x65\x6e\x20\x6c\x61\x73\x74\x20\x72\x65\x73\x75\x6c\x74\x20\x73\x74\x61\x74\x75\x73\x20\x77\x61\x73\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x65\x72\x72\x6f\x72\x4e\x6f\x50\x72\x6f\x63\x65\x73\x73\x54\x6f\x57\x61\x69\x74\x27"
);}Logger::debug ((("\x70\x69\x64\x20\x69\x73\x20\x27".$__resultPid)."\x27"));
return ($__resultPid);}sub getSig{if (($__returnedStatus==$statusDied)){(my $sig
=WTERMSIG ($__resultStatus));Logger::debug (((
"\x73\x69\x67\x6e\x61\x6c\x20\x77\x61\x73\x20\x27".$sig)."\x27"));return ($sig);
}if (($__returnedStatus==$statusStopped)){(my $sig=WSTOPSIG ($__resultStatus));
Logger::debug ((("\x73\x69\x67\x6e\x61\x6c\x20\x77\x61\x73\x20\x27".$sig)."\x27"
));return ($sig);}
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x61\x6c\x6c\x20\x74\x68\x69\x73\x20\x6d\x65\x74\x68\x6f\x64\x2c\x20\x70\x72\x65\x76\x69\x6f\x75\x73\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x73\x74\x61\x74\x75\x73\x20\x77\x61\x73\x20\x6e\x6f\x74\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x73\x74\x61\x74\x75\x73\x53\x74\x6f\x70\x70\x65\x64\x27\x20\x6f\x72\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x73\x74\x61\x74\x75\x73\x44\x69\x65\x64\x27"
);}sub getExitStatus{if (($__returnedStatus==$statusExited)){(my $exitStatus=
WEXITSTATUS ($__resultStatus));Logger::debug (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x65\x78\x69\x74\x20\x73\x74\x61\x74\x75\x73\x20\x69\x73\x20\x27"
.$exitStatus)."\x27"));return ($exitStatus);}
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x61\x6c\x6c\x20\x74\x68\x69\x73\x20\x6d\x65\x74\x68\x6f\x64\x2c\x20\x70\x72\x65\x76\x69\x6f\x75\x73\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x73\x74\x61\x74\x75\x73\x20\x77\x61\x73\x20\x6e\x6f\x74\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x73\x74\x61\x74\x75\x73\x45\x78\x69\x74\x65\x64\x27"
);}return ((0x1098+ 2894-0x1be5));
